var group__PkgBoundingVolumesRef =
[
    [ "Concepts", "group__PkgBoundingVolumesConcepts.html", "group__PkgBoundingVolumesConcepts" ],
    [ "CGAL::Approximate_min_ellipsoid_d< Traits >", "classCGAL_1_1Approximate__min__ellipsoid__d.html", [
      [ "Axes_direction_coordinate_iterator", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a7a6a1adb0e4590e5f07de50c03994de3", null ],
      [ "Axes_lengths_iterator", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a72cb50febc6d4c7c24c68a8016bde351", null ],
      [ "Cartesian_const_iterator", "classCGAL_1_1Approximate__min__ellipsoid__d.html#adf47ed5aabdb6ad61f6efac038e2fb41", null ],
      [ "Center_coordinate_iterator", "classCGAL_1_1Approximate__min__ellipsoid__d.html#aff46f1085c9c9ccb446a8e57221ae157", null ],
      [ "ET", "classCGAL_1_1Approximate__min__ellipsoid__d.html#ae80e0c15bae383fdbb2e72d8643fafc3", null ],
      [ "FT", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a700b439e58f13a26cdc86ca4d156a88c", null ],
      [ "Point", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a4a9ec257e6b8cb639810f3805316e68e", null ],
      [ "Approximate_min_ellipsoid_d", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a5fc0bc1c66b59556c903bfbc844f15fa", null ],
      [ "achieved_epsilon", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a9f9fad4c126ae57c4cd3727d9283229f", null ],
      [ "axes_lengths_begin", "classCGAL_1_1Approximate__min__ellipsoid__d.html#aeb6940806e45031a391baf58c735ec13", null ],
      [ "axes_lengths_end", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a25d9a8946ab4c81f8dbfb45dddb7f701", null ],
      [ "axis_direction_cartesian_begin", "classCGAL_1_1Approximate__min__ellipsoid__d.html#ac04a27480671bd6e5a2eb4cc01fa47e2", null ],
      [ "axis_direction_cartesian_end", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a7e8f229884c9903afa2aa39155c08f29", null ],
      [ "center_cartesian_begin", "classCGAL_1_1Approximate__min__ellipsoid__d.html#aa687dcedc9b78b06f4c0e2aba9edb592", null ],
      [ "center_cartesian_end", "classCGAL_1_1Approximate__min__ellipsoid__d.html#adb4dccfd4a16fe59e095c57d94498582", null ],
      [ "defining_matrix", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a32b71cb636acb2f6b34e96465c5379e0", null ],
      [ "defining_scalar", "classCGAL_1_1Approximate__min__ellipsoid__d.html#ad54fb77e5183d93d86840ba89ea95478", null ],
      [ "defining_vector", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a4aa3e857cdd79771f39aad531157b5f0", null ],
      [ "dimension", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a6642c2338f25f191e95232126bf9e729", null ],
      [ "is_full_dimensional", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a636b12855568f4471e0dadc3d6fefb3f", null ],
      [ "is_valid", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a2449d677fe6d12a445d5a090723d9349", null ],
      [ "number_of_points", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a747a40738dc64031ddf3bb09144c7984", null ],
      [ "traits", "classCGAL_1_1Approximate__min__ellipsoid__d.html#ad799fb3e56b6e4609963c4fd21663898", null ],
      [ "write_eps", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a1cd41640f8cf8b562772399a0fb00b13", null ]
    ] ],
    [ "CGAL::Approximate_min_ellipsoid_d_traits_2< K, ET >", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html", [
      [ "Cartesian_const_iterator", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html#a5309b1e046162e4b559cac9585c00abc", null ],
      [ "ET", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html#afb1ed3381a30852ee5fe483a710eb479", null ],
      [ "FT", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html#abf223b25a3617bdae9ccfc3cbdce7326", null ],
      [ "Point", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html#aa907d2b0f3e7736fcd6815f806fc26be", null ]
    ] ],
    [ "CGAL::Approximate_min_ellipsoid_d_traits_3< K, ET >", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html", [
      [ "Cartesian_const_iterator", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html#af5845621fee97bc1d6d68209d5b58f7c", null ],
      [ "ET", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html#a677c8508fdb25ece5021ce348431ace8", null ],
      [ "FT", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html#ac877f3c0e63bd32b12a6b5e0c3473ab8", null ],
      [ "Point", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html#a1dec6c6b90a414871287e9afd7041144", null ]
    ] ],
    [ "CGAL::Approximate_min_ellipsoid_d_traits_d< K, ET >", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html", [
      [ "Cartesian_const_iterator", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html#a84bd9b61bfc876a6a7e2c27fdd5e3898", null ],
      [ "ET", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html#a7afbc4488836e7e4525a464eef1ff5cd", null ],
      [ "FT", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html#a935d2599a3e2deb12509017bdba2b69d", null ],
      [ "Point", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html#ab8f47bce7eb1adb55c32dabdf3b2a6fa", null ]
    ] ],
    [ "CGAL::Min_annulus_d< Traits >", "classCGAL_1_1Min__annulus__d.html", [
      [ "Coordinate_iterator", "classCGAL_1_1Min__annulus__d.html#a2997ba09820a621e34e804f9edccd246", null ],
      [ "ET", "classCGAL_1_1Min__annulus__d.html#a947fa6cfa188274b8656a4380fc2d8cb", null ],
      [ "FT", "classCGAL_1_1Min__annulus__d.html#a5e8f3da81b7c3fd68ffaa21e7926c506", null ],
      [ "Inner_support_point_iterator", "classCGAL_1_1Min__annulus__d.html#a0c20e5079188e93aa2acb5c1fb613974", null ],
      [ "Outer_support_point_iterator", "classCGAL_1_1Min__annulus__d.html#ae556885096e4962c279e1ae5a186c4f8", null ],
      [ "Point", "classCGAL_1_1Min__annulus__d.html#a2c48740014712a974dc0c1f8453285e0", null ],
      [ "Point_iterator", "classCGAL_1_1Min__annulus__d.html#ade483d5f330079edfe62073b8508bac2", null ],
      [ "Support_point_iterator", "classCGAL_1_1Min__annulus__d.html#a3c45b15aeec7b0aae27f0cf16fff7f74", null ],
      [ "Min_annulus_d", "classCGAL_1_1Min__annulus__d.html#a39707371df8471cfdbbb9b972e5aee09", null ],
      [ "Min_annulus_d", "classCGAL_1_1Min__annulus__d.html#a3ffa99847e2af25dff984733c18d4006", null ],
      [ "ambient_dimension", "classCGAL_1_1Min__annulus__d.html#a2d9019c25b22659e44da35fd190f5f4a", null ],
      [ "bounded_side", "classCGAL_1_1Min__annulus__d.html#a2f1b4ff8148dad273c80ca6eb6e50917", null ],
      [ "center", "classCGAL_1_1Min__annulus__d.html#a0c448cc131ea8da6c1b116f078283059", null ],
      [ "center_coordinates_begin", "classCGAL_1_1Min__annulus__d.html#af8eea534bf4c4e5828ed92039aae7312", null ],
      [ "center_coordinates_end", "classCGAL_1_1Min__annulus__d.html#a89139a0156e8751c52de7ab4c092d786", null ],
      [ "clear", "classCGAL_1_1Min__annulus__d.html#a4787db04913c8e5f7c1edc44623d43ff", null ],
      [ "has_on_boundary", "classCGAL_1_1Min__annulus__d.html#a0b13a7e0a8187d7454825313b5d0a205", null ],
      [ "has_on_bounded_side", "classCGAL_1_1Min__annulus__d.html#a7dfb7eee2d823d64b24c3aedc4b09a9b", null ],
      [ "has_on_unbounded_side", "classCGAL_1_1Min__annulus__d.html#a7a3acf7704904ca35081556048f508b8", null ],
      [ "inner_support_points_begin", "classCGAL_1_1Min__annulus__d.html#abeea0653403645ec525b98b3f9e34345", null ],
      [ "inner_support_points_end", "classCGAL_1_1Min__annulus__d.html#a74cd561f066bb7e95a0236bac8544377", null ],
      [ "insert", "classCGAL_1_1Min__annulus__d.html#a93c945e73fee79cb711a3d7ef691c991", null ],
      [ "insert", "classCGAL_1_1Min__annulus__d.html#a6408f31e61949df71364e1afdd943f0a", null ],
      [ "is_degenerate", "classCGAL_1_1Min__annulus__d.html#a6a04e5c46956606ab2f10c23ce7ddab3", null ],
      [ "is_empty", "classCGAL_1_1Min__annulus__d.html#aac02c171c24c9aa785ed852032ec3f0b", null ],
      [ "is_valid", "classCGAL_1_1Min__annulus__d.html#a95cda026c0d457c54eca4b082c8b927c", null ],
      [ "number_of_inner_support_points", "classCGAL_1_1Min__annulus__d.html#abe0a726e40c2fe99724e5b2320e15709", null ],
      [ "number_of_outer_support_points", "classCGAL_1_1Min__annulus__d.html#a78ea64ec4199bd52cc5b7a9da84e9ffa", null ],
      [ "number_of_points", "classCGAL_1_1Min__annulus__d.html#a5d6c30e825e2e9945c7f62d0d082e8e3", null ],
      [ "number_of_support_points", "classCGAL_1_1Min__annulus__d.html#afe48650996373d948b938f464a5c30ec", null ],
      [ "outer_support_points_begin", "classCGAL_1_1Min__annulus__d.html#a8d38e76e5d422c6158bf14c66e4e69a3", null ],
      [ "outer_support_points_end", "classCGAL_1_1Min__annulus__d.html#a654aa818f6ac4179a6dd3210c0ce3a9a", null ],
      [ "points_begin", "classCGAL_1_1Min__annulus__d.html#a2ddf37e111bf90c947c835bbcda48dea", null ],
      [ "points_end", "classCGAL_1_1Min__annulus__d.html#a9a4cd744ce00a729355cae96af2da9a0", null ],
      [ "set", "classCGAL_1_1Min__annulus__d.html#a964976f7ba7313d39670022ee2881834", null ],
      [ "squared_inner_radius", "classCGAL_1_1Min__annulus__d.html#ac5f5729ec08a5b6056d214b13ac1148d", null ],
      [ "squared_inner_radius_numerator", "classCGAL_1_1Min__annulus__d.html#acd4e59293f54ad6a1d4a32239ab679e3", null ],
      [ "squared_outer_radius", "classCGAL_1_1Min__annulus__d.html#a4f5b187ebf86996b61d6a00e6220e516", null ],
      [ "squared_outer_radius_numerator", "classCGAL_1_1Min__annulus__d.html#afa384f12debe0571b2b1eb84fe8ca02b", null ],
      [ "squared_radii_denominator", "classCGAL_1_1Min__annulus__d.html#ab99e20561e5eec7dd888fae46a5ddb17", null ],
      [ "support_points_begin", "classCGAL_1_1Min__annulus__d.html#aa13d1ab896d71286f55af4e2c6d9dfb3", null ],
      [ "support_points_end", "classCGAL_1_1Min__annulus__d.html#aa9bcc33770d92957f3307a2d5eb47516", null ],
      [ "traits", "classCGAL_1_1Min__annulus__d.html#a388b4ee91e90b6bb81ec7d54ccb906bf", null ],
      [ "operator<<", "classCGAL_1_1Min__annulus__d.html#a5b3cb90ca9cbc372272fd93eecc20a3f", null ],
      [ "operator>>", "classCGAL_1_1Min__annulus__d.html#aa7aae875e52de2a0c597e6d020fe05ea", null ]
    ] ],
    [ "CGAL::Min_circle_2< Traits >", "classCGAL_1_1Min__circle__2.html", [
      [ "Circle", "classCGAL_1_1Min__circle__2.html#a48aea3450e5b91924646e784481ff44d", null ],
      [ "Point", "classCGAL_1_1Min__circle__2.html#acaff2d7da19f3c8ca5bf8845253f6039", null ],
      [ "Point_iterator", "classCGAL_1_1Min__circle__2.html#a716c27257a327f9eb570de854ccb57f4", null ],
      [ "Support_point_iterator", "classCGAL_1_1Min__circle__2.html#a694816c6d92ee807ea6a3daba1a8f421", null ],
      [ "Min_circle_2", "classCGAL_1_1Min__circle__2.html#a14b72d0065ac73ade159c3ab25855917", null ],
      [ "Min_circle_2", "classCGAL_1_1Min__circle__2.html#aebee8cf6b4ef8484b0a12f39332bc539", null ],
      [ "Min_circle_2", "classCGAL_1_1Min__circle__2.html#a1725a75ed64d54ef41c7fe3eb59931a5", null ],
      [ "Min_circle_2", "classCGAL_1_1Min__circle__2.html#aa6e065ed602ef49dcbf064d749f7cd32", null ],
      [ "Min_circle_2", "classCGAL_1_1Min__circle__2.html#ab68687584c9a3593e2316a26acc57ca5", null ],
      [ "bounded_side", "classCGAL_1_1Min__circle__2.html#a5e222fd1ba182d24bd6c10e0d31b2c75", null ],
      [ "circle", "classCGAL_1_1Min__circle__2.html#a746c29e29f7288b9a3a2741c9a207c11", null ],
      [ "clear", "classCGAL_1_1Min__circle__2.html#a3dd9c86b2ca28f8bd7d9274091d726eb", null ],
      [ "has_on_boundary", "classCGAL_1_1Min__circle__2.html#a649ea54cd5c4d679eecabe3f2e7d29b2", null ],
      [ "has_on_bounded_side", "classCGAL_1_1Min__circle__2.html#ac3c6dadb9c3289c43396f8a439c6257f", null ],
      [ "has_on_unbounded_side", "classCGAL_1_1Min__circle__2.html#a2fc4e34c6e70fffc3489f113c9ccc29c", null ],
      [ "insert", "classCGAL_1_1Min__circle__2.html#a36fb0e4da0884d5c184f9d506c93fbd3", null ],
      [ "insert", "classCGAL_1_1Min__circle__2.html#a063d28d21dc5a4a222c9fe201eb168cd", null ],
      [ "is_degenerate", "classCGAL_1_1Min__circle__2.html#a7340949b73e772788fab0a5ed2a7e005", null ],
      [ "is_empty", "classCGAL_1_1Min__circle__2.html#a6138cc0e8a507e8298a00d8070e2338f", null ],
      [ "is_valid", "classCGAL_1_1Min__circle__2.html#af773edd312c5194118bf2842ecda170a", null ],
      [ "number_of_points", "classCGAL_1_1Min__circle__2.html#ae833665313f26e701bae246cc6dea68a", null ],
      [ "number_of_support_points", "classCGAL_1_1Min__circle__2.html#ac87c3d760053509a41be898771111854", null ],
      [ "points_begin", "classCGAL_1_1Min__circle__2.html#ade14badb14c8b404d099f637ff53be87", null ],
      [ "points_end", "classCGAL_1_1Min__circle__2.html#aa98f7f868d6c7cacd137bb18cc4ec527", null ],
      [ "support_point", "classCGAL_1_1Min__circle__2.html#a5e52a11bc13981434a9b0e7c5dc6a1c8", null ],
      [ "support_points_begin", "classCGAL_1_1Min__circle__2.html#acb33d435a72cfcda800b739ba172082d", null ],
      [ "support_points_end", "classCGAL_1_1Min__circle__2.html#af808f54e70621f0fe201c4b327b5de3b", null ],
      [ "traits", "classCGAL_1_1Min__circle__2.html#a6c918bb03abf62031574a645746086ef", null ],
      [ "operator<<", "classCGAL_1_1Min__circle__2.html#a693dca04f21bc2c897f489f085a0fbff", null ],
      [ "operator>>", "classCGAL_1_1Min__circle__2.html#a8c0e384847bfe95d8f8dc7c5291547c6", null ]
    ] ],
    [ "CGAL::Min_circle_2_traits_2< K >", "classCGAL_1_1Min__circle__2__traits__2.html", [
      [ "Circle", "classCGAL_1_1Min__circle__2__traits__2.html#a4730c8f60ffb166d97304f9d0ca2f564", null ],
      [ "Point", "classCGAL_1_1Min__circle__2__traits__2.html#af428b0078814d818535ccd277e2e69ff", null ],
      [ "Min_circle_2_traits_2", "classCGAL_1_1Min__circle__2__traits__2.html#ad9f44306b03a697ddb9f29ed482a7778", null ],
      [ "Min_circle_2_traits_2", "classCGAL_1_1Min__circle__2__traits__2.html#ac1ea3bf4752819b72e3c40fc115ea5a2", null ],
      [ "orientation", "classCGAL_1_1Min__circle__2__traits__2.html#aed107bf202be6c387338c08cc20d0ad1", null ]
    ] ],
    [ "CGAL::Min_ellipse_2< Traits >", "classCGAL_1_1Min__ellipse__2.html", [
      [ "Ellipse", "classCGAL_1_1Min__ellipse__2.html#acd1b1aa7a496bc993dd231548192f1fc", null ],
      [ "Point", "classCGAL_1_1Min__ellipse__2.html#a85d7523e566c0be7444fdbc057d4ec8b", null ],
      [ "Point_iterator", "classCGAL_1_1Min__ellipse__2.html#a8179f6ba721e4fae0e56a04e08e5dd11", null ],
      [ "Support_point_iterator", "classCGAL_1_1Min__ellipse__2.html#aff8d704d738a232b81fa99c82c7cb5df", null ],
      [ "Min_ellipse_2", "classCGAL_1_1Min__ellipse__2.html#a5e7e882ef3be97366345e617b3b7b4de", null ],
      [ "Min_ellipse_2", "classCGAL_1_1Min__ellipse__2.html#a3c1fb4d1d73003f55bc28809d85e38dc", null ],
      [ "Min_ellipse_2", "classCGAL_1_1Min__ellipse__2.html#a49947e7016b29a1a6656aeeaf7045614", null ],
      [ "Min_ellipse_2", "classCGAL_1_1Min__ellipse__2.html#ae91ed5467a6f9b719a64f7d17cb30308", null ],
      [ "Min_ellipse_2", "classCGAL_1_1Min__ellipse__2.html#a23a7d4d8371623bb9741a63f1d29d041", null ],
      [ "Min_ellipse_2", "classCGAL_1_1Min__ellipse__2.html#a0428f8b9a5a58ad1c16196b94262ad9a", null ],
      [ "bounded_side", "classCGAL_1_1Min__ellipse__2.html#a965651e0633d4820cd206e498ae655fc", null ],
      [ "clear", "classCGAL_1_1Min__ellipse__2.html#ae9e4a669bf02a62d491fb6c8234388d0", null ],
      [ "ellipse", "classCGAL_1_1Min__ellipse__2.html#a8e409d48ee6822f036911ec4893b9b17", null ],
      [ "has_on_boundary", "classCGAL_1_1Min__ellipse__2.html#a2a47110a544ae513d3d2d0e225637705", null ],
      [ "has_on_bounded_side", "classCGAL_1_1Min__ellipse__2.html#a3992583c7aa438c5b0fb1b2753ffca98", null ],
      [ "has_on_unbounded_side", "classCGAL_1_1Min__ellipse__2.html#afd9664f3ff624fef94eab667c900d0b7", null ],
      [ "insert", "classCGAL_1_1Min__ellipse__2.html#a4318cb3457f776bf16af436aedd800d5", null ],
      [ "insert", "classCGAL_1_1Min__ellipse__2.html#ac2e25c8cd331a432ecb9940e0b90587f", null ],
      [ "is_degenerate", "classCGAL_1_1Min__ellipse__2.html#a1d4af8eaa19991c91d7f863cb55a8eb3", null ],
      [ "is_empty", "classCGAL_1_1Min__ellipse__2.html#a459566c59c3151ea81d6b91036ebba48", null ],
      [ "is_valid", "classCGAL_1_1Min__ellipse__2.html#af6a28f682d260c010fae1731946646cf", null ],
      [ "Min_Ellipse_2", "classCGAL_1_1Min__ellipse__2.html#a077e61fca4c81442bbcc3c8f3814c74f", null ],
      [ "number_of_points", "classCGAL_1_1Min__ellipse__2.html#adda843c9b668a7df4d43e087c55f44ef", null ],
      [ "number_of_support_points", "classCGAL_1_1Min__ellipse__2.html#a57a229ca573b9eb958b48e580b17318a", null ],
      [ "points_begin", "classCGAL_1_1Min__ellipse__2.html#a1dddfc673f54a1b6050553999cc0a400", null ],
      [ "points_end", "classCGAL_1_1Min__ellipse__2.html#abbd618de1cd53057ab4880be7ec7f99a", null ],
      [ "support_point", "classCGAL_1_1Min__ellipse__2.html#a039654b38c2fa49ffb66ac6f9e9465cf", null ],
      [ "support_points_begin", "classCGAL_1_1Min__ellipse__2.html#af778c1c16dae49ad9fc01681be5b4674", null ],
      [ "support_points_end", "classCGAL_1_1Min__ellipse__2.html#ab7b13e07ab190b99fa9385c06e9d7a7b", null ],
      [ "traits", "classCGAL_1_1Min__ellipse__2.html#adfb3289a1c1204f72a590bdc6010c073", null ],
      [ "operator<<", "classCGAL_1_1Min__ellipse__2.html#af7c0fb64d240921356e6a4e818592e42", null ],
      [ "operator>>", "classCGAL_1_1Min__ellipse__2.html#a13acc6b8559f5210d49e60513eaaf7b6", null ]
    ] ],
    [ "CGAL::Min_ellipse_2_traits_2< K >", "classCGAL_1_1Min__ellipse__2__traits__2.html", [
      [ "Ellipse", "classCGAL_1_1Min__ellipse__2__traits__2.html#afb570df476f009372ccb7f5fd34a1cd8", null ],
      [ "Point", "classCGAL_1_1Min__ellipse__2__traits__2.html#a8735671fd45fb060496e7aafa499d489", null ],
      [ "Min_ellipse_2_traits_2", "classCGAL_1_1Min__ellipse__2__traits__2.html#a4e7c9281018670b510fb47b6860681c2", null ],
      [ "Min_ellipse_2_traits_2", "classCGAL_1_1Min__ellipse__2__traits__2.html#ac4f264d9a913994a8b90fa4dc2c25e6e", null ],
      [ "double_coefficients", "classCGAL_1_1Min__ellipse__2__traits__2.html#a9323f32b47a2695404057f113fd94936", null ],
      [ "is_circle", "classCGAL_1_1Min__ellipse__2__traits__2.html#a4ab1badaf8c40c2d7e98dbfb6d9af125", null ]
    ] ],
    [ "CGAL::Min_quadrilateral_default_traits_2< K >", "structCGAL_1_1Min__quadrilateral__default__traits__2.html", [
      [ "Area_less_parallelogram_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a9cf5438dc4616b673a7434944e8a9d7a", null ],
      [ "Area_less_rectangle_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a5abad8e2016092ac67030f518c486dc7", null ],
      [ "Compare_angle_with_x_axis_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#aedd43689dcbd935cf563fe8513a0daad", null ],
      [ "Construct_direction_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#ac770dc93903fb1282fe7e5ca122678ba", null ],
      [ "Construct_line_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a33ddd2c30e3bac74315c2379558e1efd", null ],
      [ "Construct_opposite_direction_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a7503555380774978f5398385443197d6", null ],
      [ "Construct_parallelogram_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a675b9ee0ef1ec83e14dc9637a66ff599", null ],
      [ "Construct_perpendicular_vector_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a70bb1125f0ecbef1749b60b8325a3aa6", null ],
      [ "Construct_rectangle_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#ae4ef7c855d9c9fe54c3b65b5a307cd04", null ],
      [ "Construct_strip_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a57b664ae1a8b4c25d8c621c90459a66d", null ],
      [ "Construct_vector_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#acfcda71d47d7bf305b8db6fdde95f330", null ],
      [ "Construct_vector_from_direction_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a149eb7817c8c0c622c47143f0d20086d", null ],
      [ "Direction_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a41eabd8042e4903196b332b87ba49d23", null ],
      [ "Equal_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a56ed3a78eeb20aba221a64224f517ef5", null ],
      [ "Has_on_negative_side_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a517b58c333fb4e8d880c0374af26716b", null ],
      [ "Less_xy_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#ab8910b12ed91a799fabe5dfdd4f01909", null ],
      [ "Less_yx_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a7f8ce7dd722ad71d55cc369d9972472b", null ],
      [ "Line_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a4e9ff2945b566bdf517d54ea6d9d41fe", null ],
      [ "Orientation_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a1755bb78d1550b0adcdb225694d0c6c9", null ],
      [ "Parallelogram_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#aafe14dd953bbf088b95e759c9d50c053", null ],
      [ "Point_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a336faca151c17f8dc45cf347d09a4fd1", null ],
      [ "Rectangle_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a7de940837e3ea6dd89a497ee3c768a3b", null ],
      [ "Strip_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#ab5c908322e3c71b4872711feeb6e916b", null ],
      [ "Vector_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a05096f678f0136afa753dd0e6c01c1eb", null ],
      [ "Width_less_strip_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a7d5616506f89681977ae62418671fdca", null ],
      [ "construct_vector_2_object", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a1ec5a93bcd6015eef4f3b4a9534b688e", null ],
      [ "copy_parallelogram_vertices_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#ad450accfb184b13d3fb9a44076c23fea", null ],
      [ "copy_rectangle_vertices_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a9e42464b62db36b890579422a3b0cd6d", null ],
      [ "copy_strip_lines_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a82711522d257e5a16086bc69d966869f", null ]
    ] ],
    [ "CGAL::Min_sphere_annulus_d_traits_2< K, ET, NT >", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html", [
      [ "Access_coordinates_begin_d", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#abde2b2b0c54710c511cbaf924eaf2fef", null ],
      [ "Access_dimension_d", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a494549a4c89f24cfec83b0912b52815a", null ],
      [ "Construct_point_d", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a8215d935833718ce7bf9c9e93d69ced6", null ],
      [ "ET", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a49ca76cf1a2d377c92dd2826095fef0b", null ],
      [ "FT", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a50290552cca17e6814f28a484bdc09b4", null ],
      [ "NT", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a015ebf5e1c6387885dab4b326919f2a5", null ],
      [ "Point_d", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a7956736bf9198677278e460c90998feb", null ],
      [ "Rep_tag", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a18a261f426e263a0b419e05abde10a37", null ],
      [ "RT", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a7f505585e71a1211b3b238c46cc7c8f5", null ],
      [ "Min_sphere_annulus_d_traits_2", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a4e0cd742621b6f323965219a3e8cc97c", null ],
      [ "Min_sphere_annulus_d_traits_2", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#ae138c561a6a17c8365dbb768648b7753", null ],
      [ "access_coordinates_begin_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a7fe18d22eb7991c35a1b908e3b15f4a7", null ],
      [ "access_dimension_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#ab9c6b4a08b0731863d87ed8309daaf1d", null ],
      [ "construct_point_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a01a04ea4438729c7e7fc4b7f3977dc98", null ]
    ] ],
    [ "CGAL::Min_sphere_annulus_d_traits_3< K, ET, NT >", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html", [
      [ "Access_coordinates_begin_d", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a30b15dccc6a9f2561fbcf5a0c1a915c1", null ],
      [ "Access_dimension_d", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a9014bed241c83c21cf68476770ed1183", null ],
      [ "Construct_point_d", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a27c5cf94e0092a2092a3694533e95f0c", null ],
      [ "ET", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a994b5e41934e07e356aa36508c9ad21f", null ],
      [ "FT", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a29e1334b9e34d3cd5efdc04229daa63c", null ],
      [ "NT", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a1d9744b7da81792d806b055c7c5c56e5", null ],
      [ "Point_d", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a368b0a42af2b133d0aca1bc7d4941951", null ],
      [ "Rep_tag", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#ad60a09be495fb47e43e7e25c720be5ad", null ],
      [ "RT", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a4501a93b91c997ea82e119ae8436711e", null ],
      [ "Min_sphere_annulus_d_traits_3", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a74ed858cf816010300ea1840423ad0b8", null ],
      [ "Min_sphere_annulus_d_traits_3", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a35a4c51138f1aa5792deed0008ab6dc7", null ],
      [ "access_coordinates_begin_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#ad56a3c5d52a499403381c17ac9218870", null ],
      [ "access_dimension_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a5065111938a70e7d0df6a516fa1d74e4", null ],
      [ "construct_point_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a36d3313215951b052e34b10a5729a8f5", null ]
    ] ],
    [ "CGAL::Min_sphere_annulus_d_traits_d< K, ET, NT >", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html", [
      [ "Access_coordinates_begin_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a404697a19a97ad957bae7a8dd0a10a35", null ],
      [ "Access_dimension_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a693aabf86cc46f852c565206a058ef4e", null ],
      [ "Construct_point_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a60baf81455f6e0f4fcbdccbcf4855486", null ],
      [ "ET", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a8ba8eabda68c11b319337f27b74972e3", null ],
      [ "FT", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#acada74058aa1b6b40126d561f106858a", null ],
      [ "NT", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a096777dd0d94261eb5d5167b14577973", null ],
      [ "Point_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a327b226971c9acfcfdef6e682f701c33", null ],
      [ "Rep_tag", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a273612430f00867078468d3f1156fa8e", null ],
      [ "RT", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a451cacec8fb8531356e6253cd8d94fc2", null ],
      [ "Min_sphere_annulus_d_traits_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#aa9d86926bd8e03c6ac52f16ee3162226", null ],
      [ "Min_sphere_annulus_d_traits_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#af368dc4c1af1c67a6c2575266d8eb936", null ],
      [ "access_coordinates_begin_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a49b11b458f2bd2959e089e63d20c92c9", null ],
      [ "access_dimension_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#ad1f43db65695ee38409aa0fc960a6f87", null ],
      [ "construct_point_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#ae1c45fcf184cff58d90b43c4a3fe8a27", null ]
    ] ],
    [ "CGAL::Min_sphere_d< Traits >", "classCGAL_1_1Min__sphere__d.html", [
      [ "FT", "classCGAL_1_1Min__sphere__d.html#a388649f898d870cfe912dfe35aa5ebac", null ],
      [ "Point", "classCGAL_1_1Min__sphere__d.html#a6bde4249e0f11678a51745703fe01788", null ],
      [ "Point_iterator", "classCGAL_1_1Min__sphere__d.html#ad1816fab29ac1876f60a7b01042c79eb", null ],
      [ "Support_point_iterator", "classCGAL_1_1Min__sphere__d.html#aa6e1cab37215352c1036d1edad4d6c80", null ],
      [ "Min_sphere_d", "classCGAL_1_1Min__sphere__d.html#a83c9611e06db4f0cecff945cbd31c49b", null ],
      [ "Min_sphere_d", "classCGAL_1_1Min__sphere__d.html#ace8d13f062848145130056146d671fa2", null ],
      [ "ambient_dimension", "classCGAL_1_1Min__sphere__d.html#a62910f817822d46de39071ea8e219c2d", null ],
      [ "bounded_side", "classCGAL_1_1Min__sphere__d.html#a25787da8103c796a1c119c2994d4a15e", null ],
      [ "center", "classCGAL_1_1Min__sphere__d.html#a7f0aa75ed38c50e93619d4459b17835c", null ],
      [ "clear", "classCGAL_1_1Min__sphere__d.html#adce1310d8a8665b58977d3225fe4a262", null ],
      [ "has_on_boundary", "classCGAL_1_1Min__sphere__d.html#adec034ebd9ae7207cc70da0bff841f4b", null ],
      [ "has_on_bounded_side", "classCGAL_1_1Min__sphere__d.html#aa36d08deb1ecdc647d4b5bcb0d76460a", null ],
      [ "has_on_unbounded_side", "classCGAL_1_1Min__sphere__d.html#a9d7d7574f1d0a1339919a729797ab3f2", null ],
      [ "insert", "classCGAL_1_1Min__sphere__d.html#a78a9c95897a87a24024efeb0365faf15", null ],
      [ "insert", "classCGAL_1_1Min__sphere__d.html#a88261381421a7a30629a4d2b954b0890", null ],
      [ "is_degenerate", "classCGAL_1_1Min__sphere__d.html#a169e480bd56bb5ba1f07227ff84d7991", null ],
      [ "is_empty", "classCGAL_1_1Min__sphere__d.html#a11aa341b0d2a9d8751b160d1693ccce5", null ],
      [ "is_valid", "classCGAL_1_1Min__sphere__d.html#a2501c49f4df7dc1dd9207a60984a4f89", null ],
      [ "number_of_points", "classCGAL_1_1Min__sphere__d.html#a348133f4d61a2ffad9b6b0d027e70929", null ],
      [ "number_of_support_points", "classCGAL_1_1Min__sphere__d.html#adc9b70cbe20b415af91610ad2dbf6482", null ],
      [ "points_begin", "classCGAL_1_1Min__sphere__d.html#a9833b53e8a3fbbcba1a86f61476750b6", null ],
      [ "points_end", "classCGAL_1_1Min__sphere__d.html#aa48d53017616e4d26fef5073f9651cd7", null ],
      [ "set", "classCGAL_1_1Min__sphere__d.html#ade26f51bab15725c67f94c9121b827a4", null ],
      [ "squared_radius", "classCGAL_1_1Min__sphere__d.html#aae47567cad6991e4b340192339b424d6", null ],
      [ "support_points_begin", "classCGAL_1_1Min__sphere__d.html#a8484385e353b193ec77183b2b53243af", null ],
      [ "support_points_end", "classCGAL_1_1Min__sphere__d.html#ac98a21a97668704844ec0543b848d201", null ],
      [ "traits", "classCGAL_1_1Min__sphere__d.html#a33092b10644c7dddf15322373cd09595", null ],
      [ "operator<<", "classCGAL_1_1Min__sphere__d.html#a388d8ea8a3f91b3e9eef69f362372c13", null ],
      [ "operator>>", "classCGAL_1_1Min__sphere__d.html#a6204c32883cc3c5911eb90b928d6735f", null ]
    ] ],
    [ "CGAL::Min_sphere_of_points_d_traits_2< K, FT, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html", [
      [ "Algorithm", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a22361f8533225ecdff267449edf0e034", null ],
      [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a5d672099ca93a47e5722980aa9da02c4", null ],
      [ "D", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#ab2464a313c5a3407eff24d1dc9410073", null ],
      [ "FT", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a411570ae8210a97a0e1cfa1546a3eba3", null ],
      [ "Point", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#ad38ad376f839f5343bcc1f5771846e20", null ],
      [ "Radius", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#abff9b6557edb9b32fd24cbee8d4d2068", null ],
      [ "Sphere", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#ab249b16106daf82f598e01bc90ce9a4a", null ],
      [ "Use_square_roots", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a4b477b19061c673c68c56cbb976b0c80", null ],
      [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a56ff745563ec6ecfd94d712d1f86dd80", null ],
      [ "radius", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a7e11c29e4d0c0bbe74523cf03db68ae4", null ]
    ] ],
    [ "CGAL::Min_sphere_of_points_d_traits_3< K, FT, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html", [
      [ "Algorithm", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#adcd5fd5540760777a4d1a3750e1f0194", null ],
      [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a49a68ce21177cc21f478b2e180df617b", null ],
      [ "D", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a563c97ffb2d321f235918bc9b51c83ff", null ],
      [ "FT", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a249e182c1ce321deb9f57c7926b3cc3d", null ],
      [ "Point", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#ae3fa3fe0b4174c919d0d69ca63a6e575", null ],
      [ "Radius", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a70c74c82ce56ee4bbdc77a2ea588978f", null ],
      [ "Sphere", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a56d2972b1cea19de02b403542659de45", null ],
      [ "Use_square_roots", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a253b71c42409b96b9f4b23d387d318d6", null ],
      [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a02501c0c228db573467f0db4de5a0ee6", null ],
      [ "radius", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#ac2d50529ef5913a6ffba1feca9280c95", null ]
    ] ],
    [ "CGAL::Min_sphere_of_points_d_traits_d< K, FT, Dim, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html", [
      [ "Algorithm", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#aff88714939b9aa5ebda84835886840b5", null ],
      [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#af5b93f3749b8a5076058cc2c26399421", null ],
      [ "D", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#ada3cfbae652c4d9696f688d65914a260", null ],
      [ "FT", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#a7ec925d4d30b9d8e055b2d71f001d3dc", null ],
      [ "Point", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#a6de1027c19d09232cc0f0f52df772b2e", null ],
      [ "Radius", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#a7e61f3cd37fbf3e550ac4cb12a010665", null ],
      [ "Sphere", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#af2a0d80a270a4250cc9680cca610ed7e", null ],
      [ "Use_square_roots", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#a8aa3657446aeef3eedfc09c966baf189", null ],
      [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#a0e89943cc90d97c73887630723b7c6cb", null ],
      [ "radius", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#ae61a74d5ea8c75b0d792d396c7c90985", null ]
    ] ],
    [ "CGAL::Min_sphere_of_spheres_d< Traits >", "classCGAL_1_1Min__sphere__of__spheres__d.html", [
      [ "Algorithm", "classCGAL_1_1Min__sphere__of__spheres__d.html#af253e35b654e49e4c545dd2a0a1eb609", null ],
      [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__spheres__d.html#a228f584194657230bff244b0700ef3e8", null ],
      [ "FT", "classCGAL_1_1Min__sphere__of__spheres__d.html#ab2aeddc77594db89ca74d2c9266e0e04", null ],
      [ "Result", "classCGAL_1_1Min__sphere__of__spheres__d.html#ae6c835b4e3ab1df12243451ad8ded258", null ],
      [ "Sphere", "classCGAL_1_1Min__sphere__of__spheres__d.html#a0bd8553f7d26a67740e4c0a8c1dc7301", null ],
      [ "Support_iterator", "classCGAL_1_1Min__sphere__of__spheres__d.html#a0ec9be97890c91f115bd45de9cf871ca", null ],
      [ "Min_sphere_of_spheres_d", "classCGAL_1_1Min__sphere__of__spheres__d.html#a19b392958d667efdbfd025b3dfc775c4", null ],
      [ "Min_sphere_of_spheres_d", "classCGAL_1_1Min__sphere__of__spheres__d.html#a530101ba8a5848104b0c6c7f68cb747d", null ],
      [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__spheres__d.html#a979d76c29e9a2a5ea2fbda01cc26cb44", null ],
      [ "center_cartesian_end", "classCGAL_1_1Min__sphere__of__spheres__d.html#a7cc8d666c94bc4c5486472faacb54d6f", null ],
      [ "clear", "classCGAL_1_1Min__sphere__of__spheres__d.html#afa2734bbcfd23ed9ac4bb512fc72e295", null ],
      [ "discriminant", "classCGAL_1_1Min__sphere__of__spheres__d.html#ac57af1d42e76a4cb1911d2ff09447186", null ],
      [ "insert", "classCGAL_1_1Min__sphere__of__spheres__d.html#adcd37fdc4ec874d38cc5694dd64bc9cd", null ],
      [ "insert", "classCGAL_1_1Min__sphere__of__spheres__d.html#ad9f8d55ba940c8aeb59933372ecf9968", null ],
      [ "is_empty", "classCGAL_1_1Min__sphere__of__spheres__d.html#ac80672339921e1c7374557d3416c44bf", null ],
      [ "is_valid", "classCGAL_1_1Min__sphere__of__spheres__d.html#a23253e106d9623d9afedb222875fb9d0", null ],
      [ "radius", "classCGAL_1_1Min__sphere__of__spheres__d.html#a849ac2964eb50e166da93e9a5d81c4d8", null ],
      [ "set", "classCGAL_1_1Min__sphere__of__spheres__d.html#a97f3b20946efc0ddee063587f4974dca", null ],
      [ "support_begin", "classCGAL_1_1Min__sphere__of__spheres__d.html#affae999e8d10145165bb425b2ab3293a", null ],
      [ "support_end", "classCGAL_1_1Min__sphere__of__spheres__d.html#af032978c5f57bbee756051cb0bf81e9d", null ],
      [ "traits", "classCGAL_1_1Min__sphere__of__spheres__d.html#ae6e369807115adb3e978162f579b0a30", null ]
    ] ],
    [ "CGAL::Min_sphere_of_spheres_d_traits_2< K, FT, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html", [
      [ "Algorithm", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a6c92b7fe2cb8f1bba39ef95ec879fb3b", null ],
      [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a101061d82e32f576a1d5f4fc1a158da0", null ],
      [ "FT", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a9b41f81682208168838b63650e34f19b", null ],
      [ "Point", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a254c9e693df72b4b328b06b220656469", null ],
      [ "Radius", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#addd3e125403c242a5a5abc52bf0af2f8", null ],
      [ "Sphere", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#ad494791a80e85d5067c2793e8c7d8fc5", null ],
      [ "Use_square_roots", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a6189ca165f9451557ddbcfa075882c5f", null ],
      [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a8312581a56ff9a2374fefb3c86aa88b0", null ],
      [ "radius", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#ab49792a6e80e95536932502d0d016325", null ],
      [ "D", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a9795b48de19b201bce14dc76da403456", null ]
    ] ],
    [ "CGAL::Min_sphere_of_spheres_d_traits_3< K, FT, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html", [
      [ "Algorithm", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#abb101ab115309601792fe22b9c39d11e", null ],
      [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#a88ca064b1e8369a6a503452b190cfcac", null ],
      [ "FT", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#ad990e05c12488bb0e6ca4e64e3cb4ebc", null ],
      [ "Point", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#a9a07f786737e6185c80f9f0d7e8aece3", null ],
      [ "Radius", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#abd19568063f6e73eed2ceb8ccef0a168", null ],
      [ "Sphere", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#a394a39527ca124cb8493e733a0a6905a", null ],
      [ "Use_square_roots", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#ac5669a3a73035caabd3d2c97aa923245", null ],
      [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#af7133ed8ecfc03492c210f9bed93db95", null ],
      [ "radius", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#af946005502938a2216d17c5b826f748c", null ],
      [ "D", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#a705b61c967335cb3a186559898175655", null ]
    ] ],
    [ "CGAL::Min_sphere_of_spheres_d_traits_d< K, FT, Dim, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html", [
      [ "Algorithm", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#ac665c8509f8dd1c2074c384775919f87", null ],
      [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#a70b934ecfa7c1ecedfb38b002f1a29d0", null ],
      [ "FT", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#ae38a2383ac72f506360b97bd50362005", null ],
      [ "Point", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#adda8a4ce2ebc52122d2821b1ec8d3ac6", null ],
      [ "Radius", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#a431af31081196fb0b445eceb9d22815a", null ],
      [ "Sphere", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#a3fbb4330e0f575fc53458d9f7be3356b", null ],
      [ "Use_square_roots", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#ac9f8f90f90d13b5279968ffb89cc8e20", null ],
      [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#ae138595a5c312fc28ffdc7ea8b8d39ac", null ],
      [ "radius", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#a9b537faddaa9a59ad1dec6329c32be33", null ],
      [ "D", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#ac250b867de45c8fe3111cb6e3018f301", null ]
    ] ],
    [ "CGAL::Rectangular_p_center_default_traits_2< K >", "classCGAL_1_1Rectangular__p__center__default__traits__2.html", [
      [ "Construct_iso_rectangle_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#ac6118ebe2a67c15b121864f54370da22", null ],
      [ "Construct_point_2_above_left_implicit_point_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#ab1a0d959ee399743bf08d8cf28f5de5a", null ],
      [ "Construct_point_2_above_right_implicit_point_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a94daec8e0edce9ee1d7cdfb2d519a373", null ],
      [ "Construct_point_2_below_left_implicit_point_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a30013a92e42b488551041da1e4ce6d4f", null ],
      [ "Construct_point_2_below_right_implicit_point_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a864e9cc782e18013365507ab14cb655d", null ],
      [ "Construct_vertex_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a056f11c117d82cd291b94d15529a43b0", null ],
      [ "FT", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#ab3bd4a9e600b91d2d53a24e178339eb2", null ],
      [ "Infinity_distance_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a08935ac34873bde99121969a1f9db18f", null ],
      [ "Iso_rectangle_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a054a7b1fb661de15c95e8e76499ad9c7", null ],
      [ "Less_x_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a4b0a4ec2535a4f6098984af5d2971ea0", null ],
      [ "Less_y_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a66dad843f7f6fcd6cc9670483ffa5cc7", null ],
      [ "Point_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#addf92f6a95a09dea9dca610114c98224", null ],
      [ "Signed_infinity_distance_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#aa303f8de6dffcc0513e2144d76f55408", null ],
      [ "Signed_x_distance_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a83c5512285d054dd35ee026be6165865", null ],
      [ "Signed_y_distance_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#aa2e55ed8fb5f28978faa3dcea437e397", null ],
      [ "construct_iso_rectangle_2_above_left_point_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#acd39c8987848e0f438de32ad431e02f8", null ],
      [ "construct_iso_rectangle_2_above_right_point_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#aa8f649c72a10519373afb871b7fef1b1", null ],
      [ "construct_iso_rectangle_2_below_left_point_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a9f1b06179e652303e9fb792130add3ff", null ],
      [ "construct_iso_rectangle_2_below_right_point_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a5d7905fe33685e8e154c750eb0eb0be4", null ],
      [ "construct_iso_rectangle_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#aeaf94eb9415ce5a2ba24745c96b9c719", null ],
      [ "construct_vertex_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a24c5fd210267cef9b7403d997c477acd", null ],
      [ "inf_distance_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#afccd690d01b4b47136c8679c31c6d083", null ],
      [ "signed_inf_distance_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a01941caac5b00ecb76d3f474379b36b4", null ]
    ] ],
    [ "CGAL::min_parallelogram_2", "group__PkgBoundingVolumesRef.html#ga15d5706ceec6fc6fcae0b1625b6da2ac", null ],
    [ "CGAL::min_rectangle_2", "group__PkgBoundingVolumesRef.html#gadcf412afbf5ae512fc88d25d286fa3fa", null ],
    [ "CGAL::min_strip_2", "group__PkgBoundingVolumesRef.html#gafc685ec39e42e18195ca101631c61cd0", null ],
    [ "CGAL::rectangular_p_center_2", "group__PkgBoundingVolumesRef.html#ga37fae6bf8313f85322987d3f230eca53", null ]
];